@@ -5,7 +5,7 @@
 #' Stability is defined as the width of the 5th-95th percentile range, over n.reps replications of median estimates associated with sampling events. The resulting width is scaled by the population median and returned as a fraction.
 #' 
 #' @param mu map unit polygons, must have polygon ID, must be in CRS with units of meters
-#' @param r RasterLayer
+#' @param r SpatRaster
 #' @param n.set set of sampling density values to try
 #' @param n.reps number of replications
 #' @param p.id polygon ID column name
@@ -13,18 +13,18 @@
 #' @return data.frame with median stability values as percentage of population median, range: `[0,1]`
 #' @author D.E. Beaudette
 #' @export
-samplingStability <- function(mu, r, n.set=c(0.01, 0.1, 0.5, 1, 2), n.reps=10, p.id='pID') {
+samplingStability <- function(mu, r, n.set = c(0.01, 0.1, 0.5, 1, 2), n.reps = 10, p.id = 'pID') {
   
   # summary by quantiles 
   .summary <- function(i, p=c(0, 0.05, 0.25, 0.5, 0.75, 0.95, 1)) {
     # remove NA
     v <- na.omit(i)
     # compute quantiles
-    q <- quantile(v, probs=p)
+    q <- quantile(v, probs = p)
     res <- data.frame(t(q))
     
     # assign reasonable names (quantiles)
-    if(nrow(res) > 0) {
+    if (nrow(res) > 0) {
       names(res) <- c(paste0('Q', p * 100))
       # compute size
       res$n <- length(i)
@@ -37,17 +37,13 @@ samplingStability <- function(mu, r, n.set=c(0.01, 0.1, 0.5, 1, 2), n.reps=10, p
   
   # sample / raster overlay
   .sample <- function(mu, r, n, p.id) {
-    s <- constantDensitySampling(mu, n.pts.per.ac=n, min.samples=1, polygon.id=p.id)
-    e <- as.vector(raster::extract(r, s))
-    return(e)
+    s <- constantDensitySampling(mu, n.pts.per.ac = n, min.samples = 1, polygon.id = p.id)
+    terra::extract(r, s)[[2]]
   }
   
   # polygon / raster overlay
   .population <- function(mu, r) {
-    # result is a list
-    e <- raster::extract(r, mu)
-    e <- unlist(e)
-    return(e)
+    terra::extract(r, mu)[[2]]
   }
   
   # init a list to store tabular summaries
@@ -55,14 +51,13 @@ samplingStability <- function(mu, r, n.set=c(0.01, 0.1, 0.5, 1, 2), n.reps=10, p
   # get population and median
   pop <- .population(mu, r)
   pop.median <- median(pop, na.rm = TRUE)
-  n.pixels <- length(pop)
   
   # iterate over sampling densities in our example
   # this list will be used for two things:
   #    1. table of quantiles, number of samples, and pct of pixels
   #    2. medians extracted for stability index
   r.sample <- list()
-  for(i in n.set) {
+  for (i in n.set) {
     # estimate select quantiles and sample size over replications
     # result is a list
     s.i <- replicate(n.reps, .summary(.sample(mu, r, i, p.id)), simplify = FALSE)
@@ -93,7 +88,7 @@ samplingStability <- function(mu, r, n.set=c(0.01, 0.1, 0.5, 1, 2), n.reps=10, p
   # compute 5th--95th pctile interval across all samples
   stability <- ldply(r.sample, function(i) {
     # get interval
-    qq <- quantile(i[['Q50']], probs=c(0.05, 0.95))
+    qq <- quantile(i[['Q50']], probs = c(0.05, 0.95))
     qq <- abs(diff(qq))
     # scale interval size relative to population median
     return(qq / pop.median)
@@ -103,7 +98,7 @@ samplingStability <- function(mu, r, n.set=c(0.01, 0.1, 0.5, 1, 2), n.reps=10, p
   names(stability) <- c('sampling.density', 'stability')
   names(summary.table)[1] <- 'sampling.density'
   
-  return(list(summary.table=summary.table, stability=stability))
+  return(list(summary.table = summary.table, stability = stability))
 }
 
 
