@@ -16,19 +16,21 @@
 #' 
 #' @param cols vector of colors
 #' 
+#' @param \dots additional arguments to `[iterateHydOrder]`: `target = 0.9, maxIter = 20, j.amount = 0.05, verbose = FALSE`
 #' 
 #' @return
 #' A `list` with the following elements:
 #'    * `fig`: lattice object (the figure)
 #'    * `order`: 1D ordering from `cluster::diana`
-#'    * `clust`: clustering object returned by `cluster::diana`
+#'    * `clust`: `hclust` object
+#'    * `match.rate`: fraction of series matching target hydrologic ordering, after clustering + rotation
 #' 
 #' @details See the \href{http://ncss-tech.github.io/AQP/soilDB/soil-series-query-functions.html}{Soil Series Query Functions} tutorial for more information.
 #' 
 #' @author D.E. Beaudette
 #' 
 #' 
-vizSurfaceShape <- function(x, title = 'Surface Shape', s = NULL, annotations = TRUE, annotation.cex = 0.75, cols = c("#2B83BA", "#FFFFBF", "#D7191C", "#808080", "darkgreen")) {
+vizSurfaceShape <- function(x, title = 'Surface Shape', s = NULL, annotations = TRUE, annotation.cex = 0.75, cols = c("#2B83BA", "#FFFFBF", "#D7191C", "#808080", "darkgreen"), ...) {
   
   # sanity checks on input
   if(!inherits(x, 'data.frame')) {
@@ -78,17 +80,14 @@ vizSurfaceShape <- function(x, title = 'Surface Shape', s = NULL, annotations =
   
   ## all of the fancy ordering + dendrogram require > 1 series
   if(n.series > 1) {
-    # re-order labels based on sorting of proportions: "hydrologic" ordering
-    hyd.order <- order(rowSums(sweep(x[, -1], 2, STATS = c(-4, 1, 4, 5, 6), FUN = '*')), decreasing = TRUE)
     
-    # cluster proportions: results are not in "hydrologic" order, but close
-    x.d <- as.hclust(diana(daisy(x[, -1])))
-    
-    # rotate clustering according to hydrologic ordering
-    x.d.hydro <- dendextend::rotate(x.d, order = x$series[hyd.order]) # dendextend approach
+    # iteratively apply hydrologic ordering, 
+    .res <- iterateHydOrder(x, g = 'shape', ...)
+    x.d.hydro <- .res$clust
+    .match.rate <- .res$match.rate
     
     # re-order labels levels based on clustering
-    x.long$series <- factor(x.long$series, levels = x.long$series[x.d.hydro$order])
+    x.long$series <- factor(x.long$series, levels = x$series[x.d.hydro$order])
     
     # dendrogram synced to bars
     leg <- list(
@@ -96,8 +95,8 @@ vizSurfaceShape <- function(x, title = 'Surface Shape', s = NULL, annotations =
         fun = latticeExtra::dendrogramGrob,
         args = list(
           x = as.dendrogram(x.d.hydro), 
-          side="right", 
-          size=10)
+          side = "right", 
+          size = 10)
       )
     )
     
@@ -110,6 +109,7 @@ vizSurfaceShape <- function(x, title = 'Surface Shape', s = NULL, annotations =
     
     # simulate output from clustering
     x.d.hydro <- list(order = 1L)
+    .match.rate <- NA
   }
   
   
@@ -187,8 +187,12 @@ vizSurfaceShape <- function(x, title = 'Surface Shape', s = NULL, annotations =
   # embed styling
   pp <- update(pp, par.settings = tps)
   
-  # figure, ordering, clustering object
-  res <- list(fig = pp, order = x.d.hydro$order, clust = x.d.hydro)
-  return(res)
+  # re-pack results
+  res <- list(
+    fig = pp, 
+    order = x.d.hydro$order, 
+    clust = x.d.hydro, 
+    match.rate = .match.rate
+  )
 }
 
